@@ -4,6 +4,7 @@ from .evaluation_cross_validation_task import EvaluationCrossValidationTask
 from .feature_selection_cross_validation_task import FeatureSelectionCrossValidationTask
 from .hyperparameters_search_cross_validation_task import HyperParametersSearchCrossValidationTask
 from .train_task import TrainTask
+from .prediction_task import PredictionTask
 
 __all__ = [
     "BaseTask",
@@ -11,5 +12,6 @@ __all__ = [
     "EvaluationCrossValidationTask",
     "FeatureSelectionCrossValidationTask",
     "HyperParametersSearchCrossValidationTask",
-    "TrainTask"
+    "TrainTask",
+    "PredictionTask"
 ]
\ No newline at end of file
